pub struct RtCreateProjectInput {Show 13 fields
pub name: String,
pub team_ids: Vec<String>,
pub description: Option<String>,
pub content: Option<String>,
pub icon: Option<String>,
pub color: Option<String>,
pub status_id: Option<String>,
pub priority: Option<i32>,
pub lead_id: Option<String>,
pub start_date: Option<String>,
pub target_date: Option<String>,
pub member_ids: Option<Vec<String>>,
pub label_ids: Option<Vec<String>>,
}Fields
name: Stringteam_ids: Vec<String>description: Option<String>content: Option<String>icon: Option<String>color: Option<String>status_id: Option<String>priority: Option<i32>lead_id: Option<String>start_date: Option<String>target_date: Option<String>member_ids: Option<Vec<String>>label_ids: Option<Vec<String>>Trait Implementations
Sourceimpl<UT> ConvertError<UT> for RtCreateProjectInput
impl<UT> ConvertError<UT> for RtCreateProjectInput
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<UT> FfiConverter<UT> for RtCreateProjectInput
impl<UT> FfiConverter<UT> for RtCreateProjectInput
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for RtCreateProjectInput
impl<UT> Lift<UT> for RtCreateProjectInput
Sourceimpl<UT> LiftRef<UT> for RtCreateProjectInput
impl<UT> LiftRef<UT> for RtCreateProjectInput
Sourceimpl<UT> LiftReturn<UT> for RtCreateProjectInput
impl<UT> LiftReturn<UT> for RtCreateProjectInput
Sourcetype ReturnType = <RtCreateProjectInput as Lift<UT>>::FfiType
type ReturnType = <RtCreateProjectInput as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for RtCreateProjectInput
impl<UT> Lower<UT> for RtCreateProjectInput
type FfiType = <RtCreateProjectInput as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for RtCreateProjectInput
impl<UT> LowerError<UT> for RtCreateProjectInput
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for RtCreateProjectInput
impl<UT> LowerReturn<UT> for RtCreateProjectInput
Sourcetype ReturnType = <RtCreateProjectInput as Lower<UT>>::FfiType
type ReturnType = <RtCreateProjectInput as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl<UT> TypeId<UT> for RtCreateProjectInput
impl<UT> TypeId<UT> for RtCreateProjectInput