pub struct RtHydrationResourceState {
pub resource: RtHydrationResource,
pub status: RtHydrationStatus,
pub source_updated_at: String,
pub last_attempted_at: Option<String>,
pub hydrated_at: Option<String>,
pub attempt_count: u32,
pub next_retry_at: Option<String>,
pub last_error: Option<String>,
}Fields
resource: RtHydrationResourcestatus: RtHydrationStatussource_updated_at: Stringlast_attempted_at: Option<String>hydrated_at: Option<String>attempt_count: u32next_retry_at: Option<String>last_error: Option<String>Trait Implementations
Sourceimpl Clone for RtHydrationResourceState
impl Clone for RtHydrationResourceState
Sourcefn clone(&self) -> RtHydrationResourceState
fn clone(&self) -> RtHydrationResourceState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for RtHydrationResourceState
impl<UT> ConvertError<UT> for RtHydrationResourceState
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for RtHydrationResourceState
impl Debug for RtHydrationResourceState
impl Eq for RtHydrationResourceState
Sourceimpl<UT> FfiConverter<UT> for RtHydrationResourceState
impl<UT> FfiConverter<UT> for RtHydrationResourceState
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<HydrationResourceState> for RtHydrationResourceState
impl From<HydrationResourceState> for RtHydrationResourceState
Sourcefn from(value: HydrationResourceState) -> Self
fn from(value: HydrationResourceState) -> Self
Converts to this type from the input type.
Sourceimpl<UT> Lift<UT> for RtHydrationResourceState
impl<UT> Lift<UT> for RtHydrationResourceState
Sourceimpl<UT> LiftRef<UT> for RtHydrationResourceState
impl<UT> LiftRef<UT> for RtHydrationResourceState
Sourceimpl<UT> LiftReturn<UT> for RtHydrationResourceState
impl<UT> LiftReturn<UT> for RtHydrationResourceState
Sourcetype ReturnType = <RtHydrationResourceState as Lift<UT>>::FfiType
type ReturnType = <RtHydrationResourceState as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for RtHydrationResourceState
impl<UT> Lower<UT> for RtHydrationResourceState
type FfiType = <RtHydrationResourceState as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for RtHydrationResourceState
impl<UT> LowerError<UT> for RtHydrationResourceState
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for RtHydrationResourceState
impl<UT> LowerReturn<UT> for RtHydrationResourceState
Sourcetype ReturnType = <RtHydrationResourceState as Lower<UT>>::FfiType
type ReturnType = <RtHydrationResourceState as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl PartialEq for RtHydrationResourceState
impl PartialEq for RtHydrationResourceState
impl StructuralPartialEq for RtHydrationResourceState
Sourceimpl<UT> TypeId<UT> for RtHydrationResourceState
impl<UT> TypeId<UT> for RtHydrationResourceState