pub struct RtIssue {Show 15 fields
pub id: String,
pub identifier: String,
pub team_key: String,
pub title: String,
pub description: Option<String>,
pub state_name: String,
pub state_type: String,
pub priority: i32,
pub assignee_name: Option<String>,
pub project_name: Option<String>,
pub labels: Vec<String>,
pub created_at: String,
pub updated_at: String,
pub url: String,
pub branch_name: Option<String>,
}Fields
id: Stringidentifier: Stringteam_key: Stringtitle: Stringdescription: Option<String>state_name: Stringstate_type: Stringpriority: i32assignee_name: Option<String>project_name: Option<String>labels: Vec<String>created_at: Stringupdated_at: Stringurl: Stringbranch_name: Option<String>Trait Implementations
Sourceimpl<UT> ConvertError<UT> for RtIssue
impl<UT> ConvertError<UT> for RtIssue
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<UT> FfiConverter<UT> for RtIssue
impl<UT> FfiConverter<UT> for RtIssue
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> LiftReturn<UT> for RtIssue
impl<UT> LiftReturn<UT> for RtIssue
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> LowerError<UT> for RtIssue
impl<UT> LowerError<UT> for RtIssue
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for RtIssue
impl<UT> LowerReturn<UT> for RtIssue
Sourcetype ReturnType = <RtIssue as Lower<UT>>::FfiType
type ReturnType = <RtIssue as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more