pub struct RtProject {Show 25 fields
pub id: String,
pub workspace_id: String,
pub slug_id: String,
pub name: String,
pub description: String,
pub content: Option<String>,
pub icon: Option<String>,
pub color: String,
pub status_id: String,
pub status_name: String,
pub status_type: String,
pub status_color: String,
pub priority: i32,
pub start_date: Option<String>,
pub target_date: Option<String>,
pub lead_id: Option<String>,
pub lead_name: Option<String>,
pub created_at: String,
pub updated_at: String,
pub archived_at: Option<String>,
pub url: String,
pub progress: f64,
pub teams: Vec<RtProjectTeam>,
pub members: Vec<RtProjectMember>,
pub labels: Vec<RtProjectLabel>,
}Fields
id: Stringworkspace_id: Stringslug_id: Stringname: Stringdescription: Stringcontent: Option<String>icon: Option<String>color: Stringstatus_id: Stringstatus_name: Stringstatus_type: Stringstatus_color: Stringpriority: i32start_date: Option<String>target_date: Option<String>lead_id: Option<String>lead_name: Option<String>created_at: Stringupdated_at: Stringarchived_at: Option<String>url: Stringprogress: f64teams: Vec<RtProjectTeam>members: Vec<RtProjectMember>labels: Vec<RtProjectLabel>Trait Implementations
Sourceimpl<UT> ConvertError<UT> for RtProject
impl<UT> ConvertError<UT> for RtProject
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<UT> FfiConverter<UT> for RtProject
impl<UT> FfiConverter<UT> for RtProject
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> LiftReturn<UT> for RtProject
impl<UT> LiftReturn<UT> for RtProject
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> LowerError<UT> for RtProject
impl<UT> LowerError<UT> for RtProject
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for RtProject
impl<UT> LowerReturn<UT> for RtProject
Sourcetype ReturnType = <RtProject as Lower<UT>>::FfiType
type ReturnType = <RtProject as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more