pub struct RtProjectMilestone {Show 13 fields
pub id: String,
pub workspace_id: String,
pub project_id: String,
pub project_name: String,
pub name: String,
pub description: Option<String>,
pub target_date: Option<String>,
pub status: String,
pub progress: f64,
pub sort_order: f64,
pub created_at: String,
pub updated_at: String,
pub archived_at: Option<String>,
}Fields
id: Stringworkspace_id: Stringproject_id: Stringproject_name: Stringname: Stringdescription: Option<String>target_date: Option<String>status: Stringprogress: f64sort_order: f64created_at: Stringupdated_at: Stringarchived_at: Option<String>Trait Implementations
Sourceimpl<UT> ConvertError<UT> for RtProjectMilestone
impl<UT> ConvertError<UT> for RtProjectMilestone
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<UT> FfiConverter<UT> for RtProjectMilestone
impl<UT> FfiConverter<UT> for RtProjectMilestone
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<ProjectMilestone> for RtProjectMilestone
impl From<ProjectMilestone> for RtProjectMilestone
Sourcefn from(milestone: ProjectMilestone) -> Self
fn from(milestone: ProjectMilestone) -> Self
Converts to this type from the input type.
Sourceimpl<UT> Lift<UT> for RtProjectMilestone
impl<UT> Lift<UT> for RtProjectMilestone
Sourceimpl<UT> LiftRef<UT> for RtProjectMilestone
impl<UT> LiftRef<UT> for RtProjectMilestone
Sourceimpl<UT> LiftReturn<UT> for RtProjectMilestone
impl<UT> LiftReturn<UT> for RtProjectMilestone
Sourcetype ReturnType = <RtProjectMilestone as Lift<UT>>::FfiType
type ReturnType = <RtProjectMilestone as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for RtProjectMilestone
impl<UT> Lower<UT> for RtProjectMilestone
type FfiType = <RtProjectMilestone as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for RtProjectMilestone
impl<UT> LowerError<UT> for RtProjectMilestone
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for RtProjectMilestone
impl<UT> LowerReturn<UT> for RtProjectMilestone
Sourcetype ReturnType = <RtProjectMilestone as Lower<UT>>::FfiType
type ReturnType = <RtProjectMilestone as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl<UT> TypeId<UT> for RtProjectMilestone
impl<UT> TypeId<UT> for RtProjectMilestone