pub struct RtTeamSummary {
pub key: String,
pub issue_count: u64,
pub embedded_count: u64,
pub last_synced_at: Option<String>,
}Fields
key: Stringissue_count: u64embedded_count: u64last_synced_at: Option<String>Trait Implementations
Sourceimpl<UT> ConvertError<UT> for RtTeamSummary
impl<UT> ConvertError<UT> for RtTeamSummary
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<UT> FfiConverter<UT> for RtTeamSummary
impl<UT> FfiConverter<UT> for RtTeamSummary
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<TeamSummary> for RtTeamSummary
impl From<TeamSummary> for RtTeamSummary
Sourcefn from(t: TeamSummary) -> Self
fn from(t: TeamSummary) -> Self
Converts to this type from the input type.
Sourceimpl<UT> Lift<UT> for RtTeamSummary
impl<UT> Lift<UT> for RtTeamSummary
Sourceimpl<UT> LiftRef<UT> for RtTeamSummary
impl<UT> LiftRef<UT> for RtTeamSummary
type LiftType = RtTeamSummary
Sourceimpl<UT> LiftReturn<UT> for RtTeamSummary
impl<UT> LiftReturn<UT> for RtTeamSummary
Sourcetype ReturnType = <RtTeamSummary as Lift<UT>>::FfiType
type ReturnType = <RtTeamSummary as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for RtTeamSummary
impl<UT> Lower<UT> for RtTeamSummary
type FfiType = <RtTeamSummary as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for RtTeamSummary
impl<UT> LowerError<UT> for RtTeamSummary
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for RtTeamSummary
impl<UT> LowerReturn<UT> for RtTeamSummary
Sourcetype ReturnType = <RtTeamSummary as Lower<UT>>::FfiType
type ReturnType = <RtTeamSummary as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl<UT> TypeId<UT> for RtTeamSummary
impl<UT> TypeId<UT> for RtTeamSummary